@@ -836,13 +836,17 @@ class Structure(UniqueMixin, metaclass=StructMeta):
             if getattr(self, "_instantiated", False):
                 raise ValueError(f"{self.__class__.__name__}: Structure is immutable")
             value = deepcopy(value)
-        if not any([
-            getattr(self, ADDITIONAL_PROPERTIES, True),
-            key in self.get_all_fields_by_name(),
-            _is_sunder(key),
-            _is_dunder(key)
-        ]):
-            raise ValueError(f"{self.__class__.__name__}: trying to set a non-field '{key}' is not allowed")
+        if not any(
+            [
+                getattr(self, ADDITIONAL_PROPERTIES, True),
+                key in self.get_all_fields_by_name(),
+                _is_sunder(key),
+                _is_dunder(key),
+            ]
+        ):
+            raise ValueError(
+                f"{self.__class__.__name__}: trying to set a non-field '{key}' is not allowed"
+            )
         if all(
             [
                 getattr(self, IGNORE_NONE_VALUES, False),
@@ -1164,48 +1168,107 @@ class Structure(UniqueMixin, metaclass=StructMeta):
     @classmethod
     def omit(cls, *fields_to_omit, class_name: str = ""):
         """
-            Define a new Structure class with all the fields of the given class, except for the omitted ones.
-             For Example:
+        Define a new Structure class with all the fields of the given class, except for the omitted ones.
+         For Example:
 
-             .. code-block:: python
+         .. code-block:: python
 
-                 class Foo(ImmutableStructure):
-                    i: int
-                    d: dict[str, int] = dict
-                    s: set
-                    a: str
-                    b: Integer
+             class Foo(ImmutableStructure):
+                i: int
+                d: dict[str, int] = dict
+                s: set
+                a: str
+                b: Integer
 
-                 class Bar(Foo.omit("a", "b")):
-                    x: int
+             class Bar(Foo.omit("a", "b")):
+                x: int
 
-            "Bar" has the fields: i, d, s, x. Note that Bar does not extend Foo, but it is a Structure class.
-             It does copy attributes like serialization mappers, _ignore_none, _additionalProperties,
-            but Bar can override any of them.
+        "Bar" has the fields: i, d, s, x. Note that Bar does not extend Foo, but it is a Structure class.
+         It does copy attributes like serialization mappers, _ignore_none,
+        but Bar can override any of them.
 
-            Another valid usage:
+        Another valid usage:
 
-            .. code-block:: python
+        .. code-block:: python
 
-                Bar = Foo.omit("a", "b", "i", "s")
-                bar = Bar(d={"a": 5})
+            Bar = Foo.omit("a", "b", "i", "s")
+            bar = Bar(d={"a": 5})
 
         """
-        attributes_to_include = {"_fields", ADDITIONAL_PROPERTIES, SERIALIZATION_MAPPER,
-                                 DESERIALIZATION_MAPPER, IGNORE_NONE_VALUES, DEFAULTS}
+        attributes_to_include = {
+            "_fields",
+            SERIALIZATION_MAPPER,
+            DESERIALIZATION_MAPPER,
+            IGNORE_NONE_VALUES,
+            DEFAULTS,
+        }
         cls_dict = {}
         for k, v in cls.__dict__.items():
             if k in attributes_to_include:
                 cls_dict[k] = v
             elif k in cls.get_all_fields_by_name() and k not in fields_to_omit:
                 cls_dict[k] = v
-        cls_dict[REQUIRED_FIELDS] = [x for x in getattr(cls, REQUIRED_FIELDS) if x not in fields_to_omit]
+        cls_dict[REQUIRED_FIELDS] = [
+            x for x in getattr(cls, REQUIRED_FIELDS) if x not in fields_to_omit
+        ]
 
         classname = class_name if class_name else f"Omit{cls.__name__}"
         newclass = type(classname, (Structure,), cls_dict)
 
         return newclass
 
+    @classmethod
+    def pick(cls, *fields_to_pick, class_name: str = ""):
+        """
+        Define a new Structure class with that picks specific fields from a predefined class.
+         For Example:
+
+         .. code-block:: python
+
+             class Foo(ImmutableStructure):
+                i: int
+                d: dict[str, int] = dict
+                s: set
+                a: str
+                b: Integer
+
+             class Bar(Foo.pick("a", "b")):
+                x: int
+
+        "Bar" has the fields: a, b, x. Note that Bar does not extend Foo, but it is a Structure class.
+         It does copy attributes like serialization mappers, _ignore_none,
+        but Bar can override any of them.
+
+        Another valid usage:
+
+        .. code-block:: python
+
+            Bar = Foo.pick("d")
+            bar = Bar(d={"a": 5})
+
+        """
+        attributes_to_include = {
+            "_fields",
+            SERIALIZATION_MAPPER,
+            DESERIALIZATION_MAPPER,
+            IGNORE_NONE_VALUES,
+            DEFAULTS,
+        }
+        cls_dict = {}
+        for k, v in cls.__dict__.items():
+            if k in attributes_to_include:
+                cls_dict[k] = v
+            elif k in cls.get_all_fields_by_name() and k in fields_to_pick:
+                cls_dict[k] = v
+        cls_dict[REQUIRED_FIELDS] = [
+            x for x in getattr(cls, REQUIRED_FIELDS) if x in fields_to_pick
+        ]
+
+        classname = class_name if class_name else f"Pick{cls.__name__}"
+        newclass = type(classname, (Structure,), cls_dict)
+
+        return newclass
+
 
 class FinalStructure(Structure):
     pass
@@ -1373,13 +1436,31 @@ class ImmutableField(Field):
 
 
 class PartialMeta(type):
-    def __getitem__(cls, clazz: typing.Union[StructMeta, typing.Tuple[StructMeta, str]]):
+    def __getitem__(
+        cls, clazz: typing.Union[StructMeta, typing.Tuple[StructMeta, str]]
+    ):
         if not isinstance(clazz, StructMeta):
-            if not isinstance(clazz, tuple) or (isinstance(clazz, tuple) and (len(clazz)!=2 or not isinstance(clazz[0], StructMeta) or not isinstance(clazz[1], str))):
-                raise TypeError("Partial must have a Structure class as a parameter, and an optional name for the class")
-        clazz, classname = clazz if isinstance(clazz, tuple) else (clazz, f"Partial{clazz.__name__}")
-        attributes_to_include = {"_fields", ADDITIONAL_PROPERTIES, SERIALIZATION_MAPPER,
-                                 DESERIALIZATION_MAPPER, IGNORE_NONE_VALUES, DEFAULTS}
+            if not isinstance(clazz, tuple) or (
+                isinstance(clazz, tuple)
+                and (
+                    len(clazz) != 2
+                    or not isinstance(clazz[0], StructMeta)
+                    or not isinstance(clazz[1], str)
+                )
+            ):
+                raise TypeError(
+                    "Partial must have a Structure class as a parameter, and an optional name for the class"
+                )
+        clazz, classname = (
+            clazz if isinstance(clazz, tuple) else (clazz, f"Partial{clazz.__name__}")
+        )
+        attributes_to_include = {
+            "_fields",
+            SERIALIZATION_MAPPER,
+            DESERIALIZATION_MAPPER,
+            IGNORE_NONE_VALUES,
+            DEFAULTS,
+        }
         cls_dict = {}
         for k, v in clazz.__dict__.items():
             if k in attributes_to_include or (not _is_sunder(k) and not _is_dunder(k)):
@@ -1408,7 +1489,7 @@ class Partial(metaclass=PartialMeta):
             x: str
 
     "Bar" has all the fields of Foo as optional, and in addition "x" as required. Note that Bar does not extend Foo, but
-    it is a Structure class. It does copy attributes like serialization mappers, _ignore_none, _additionalProperties,
+    it is a Structure class. It does copy attributes like serialization mappers, _ignore_none,
     but Bar can override any of them.
 
     Another valid usage:
@@ -1423,17 +1504,37 @@ class Partial(metaclass=PartialMeta):
         Bar = Partial[Foo, "Bar"]
 
     """
+
     _required = []
 
 
 class ExtendMeta(type):
-    def __getitem__(cls, clazz: typing.Union[StructMeta, typing.Tuple[StructMeta, str]]):
+    def __getitem__(
+        cls, clazz: typing.Union[StructMeta, typing.Tuple[StructMeta, str]]
+    ):
         if not isinstance(clazz, StructMeta):
-            if not isinstance(clazz, tuple) or (isinstance(clazz, tuple) and (len(clazz)!=2 or not isinstance(clazz[0], StructMeta) or not isinstance(clazz[1], str))):
-                raise TypeError("Extend must have a Structure class as a parameter, and an optional name for the class")
-        clazz, classname = clazz if isinstance(clazz, tuple) else (clazz, f"Extend{clazz.__name__}")
-        attributes_to_include = {"_fields", ADDITIONAL_PROPERTIES, SERIALIZATION_MAPPER, REQUIRED_FIELDS,
-                                 DESERIALIZATION_MAPPER, IGNORE_NONE_VALUES, DEFAULTS}
+            if not isinstance(clazz, tuple) or (
+                isinstance(clazz, tuple)
+                and (
+                    len(clazz) != 2
+                    or not isinstance(clazz[0], StructMeta)
+                    or not isinstance(clazz[1], str)
+                )
+            ):
+                raise TypeError(
+                    "Extend must have a Structure class as a parameter, and an optional name for the class"
+                )
+        clazz, classname = (
+            clazz if isinstance(clazz, tuple) else (clazz, f"Extend{clazz.__name__}")
+        )
+        attributes_to_include = {
+            "_fields",
+            SERIALIZATION_MAPPER,
+            REQUIRED_FIELDS,
+            DESERIALIZATION_MAPPER,
+            IGNORE_NONE_VALUES,
+            DEFAULTS,
+        }
         cls_dict = {}
         for k, v in clazz.__dict__.items():
             if k in attributes_to_include or (not _is_sunder(k) and not _is_dunder(k)):
@@ -1446,36 +1547,145 @@ class ExtendMeta(type):
 
 class Extend(metaclass=ExtendMeta):
     """
-       Define a new Structure class with all the fields of the given class
-       For Example:
+    Define a new Structure class with all the fields of the given class
+    For Example:
 
-        .. code-block:: python
+     .. code-block:: python
 
-            class Foo(ImmutableStructure):
-               i: int
-               d: dict[str, int] = dict
-               s: str
-               a: set
+         class Foo(ImmutableStructure):
+            i: int
+            d: dict[str, int] = dict
+            s: str
+            a: set
 
-            class Bar(Extend[Foo]):
-               x: str
+         class Bar(Extend[Foo]):
+            x: str
 
-       "Bar" has all the fields of Foo, and in addition "x". So the required fields in this case are i, s, a, x
-       (since d has a default value).
-       Note that Bar does not extend Foo, but it is a Structure class.
-       It does copy attributes like serialization mappers, _ignore_none, _additionalProperties, but Bar can override
-       any of them.
+    "Bar" has all the fields of Foo, and in addition "x". So the required fields in this case are i, s, a, x
+    (since d has a default value).
+    Note that Bar does not extend Foo, but it is a Structure class.
+    It does copy attributes like serialization mappers, _ignore_none, but Bar can override
+    any of them.
 
-       Another valid usage:
+    Another valid usage:
 
-       .. code-block:: python
+    .. code-block:: python
 
-           Bar = Extend[Foo]
+        Bar = Extend[Foo]
 
-           bar = Bar(i=5)
+        bar = Bar(i=5)
 
-           # or if you want to have a consistent class name for troubleshooting:
-           Bar = Partial[Foo, "Bar"]
+        # or if you want to have a consistent class name for troubleshooting:
+        Bar = Partial[Foo, "Bar"]
 
     """
+
+    pass
+
+
+class OmitMeta(type):
+    def __getitem__(
+        cls,
+        params: typing.Union[
+            typing.Tuple[StructMeta, Iterable[str], str],
+            typing.Tuple[StructMeta, Iterable[str]],
+        ],
+    ):
+        if (
+            not isinstance(params, tuple)
+            or not 1 < len(params) < 4
+            or not isinstance(params[0], StructMeta)
+        ):
+            raise TypeError(
+                "Omit accepts the source class name, a list of fields, and an optional name for the new class it creates"
+            )
+        clazz, fields, *new_name_maybe = params
+        class_name = new_name_maybe[0] if new_name_maybe else f"Omit{clazz.__name__}"
+        return clazz.omit(*fields, class_name=class_name)
+
+
+class Omit(metaclass=OmitMeta):
+    """
+    Define a new Structure class with all the fields of the given class, except for the omitted ones.
+     For Example:
+
+     .. code-block:: python
+
+         class Foo(ImmutableStructure):
+            i: int
+            d: dict[str, int] = dict
+            s: set
+            a: str
+            b: Integer
+
+         class Bar(Omit[Foo, ("a", "b")]):
+            x: int
+
+    "Bar" has the fields: i, d, s, x. Note that Bar does not extend Foo, but it is a Structure class.
+     It does copy attributes like serialization mappers, _ignore_none,
+    but Bar can override any of them.
+
+    Another valid usage:
+
+    .. code-block:: python
+
+        Bar = Omit[Foo, ("a", "b", "i", "s"), class_name="Bar"]
+        bar = Bar(d={"a": 5})
+
+    """
+
+    pass
+
+
+class PickMeta(type):
+    def __getitem__(
+        cls,
+        params: typing.Union[
+            typing.Tuple[StructMeta, Iterable[str], str],
+            typing.Tuple[StructMeta, Iterable[str]],
+        ],
+    ):
+        if (
+            not isinstance(params, tuple)
+            or not 1 < len(params) < 4
+            or not isinstance(params[0], StructMeta)
+        ):
+            raise TypeError(
+                "Pick accepts the source class name, a list of fields, and an optional name for the new class it creates"
+            )
+        clazz, fields, *new_name_maybe = params
+        class_name = new_name_maybe[0] if new_name_maybe else f"Pick{clazz.__name__}"
+        return clazz.pick(*fields, class_name=class_name)
+
+
+class Pick(metaclass=PickMeta):
+    """
+    Define a new Structure class with that picks specific fields from a predefined class.
+     For Example:
+
+     .. code-block:: python
+
+         class Foo(ImmutableStructure):
+            i: int
+            d: dict[str, int] = dict
+            s: set
+            a: str
+            b: Integer
+
+         class Bar(Pick[Foo, ("a", "b")]):
+            x: int
+
+    "Bar" has the fields: a, b, x. Note that Bar does not extend Foo, but it is a Structure class.
+     It does copy attributes like serialization mappers, _ignore_none,
+    but Bar can override any of them.
+
+    Another valid usage:
+
+    .. code-block:: python
+
+        Bar = Pick[Foo, ("d"), class_name="Bar"]
+        bar = Bar(d={"a": 5})
+
+    """
+
     pass
